#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info:
##    Example of how to use libnotify correctly and at the same time comply to
##    the new jaunty notification spec (read: visual guidelines)
##
## Run:
##    chmod +x sd-example-using-button-tint-hint.py
##    ./sd-example-using-button-tint-hint.py
##
## Copyright 2012 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import sys
import time
import pynotify
import gobject
import example

def action_decline (notification, action):
    if action == "decline_id":
        print("Declined")
    else:
        print("That should not have happened (action_decline)!")

def action_ok (notification, action):
    if action == "ok_id":
        print("Ok")
    else:
        print("That should not have happened (action_ok)!")

def pushNotification (title, body, icon):
    n = pynotify.Notification (title, body, icon);

    # NOTE: the order in which actions are added is important... positive
    # always comes first!
    n.add_action ("ok_id",      "Ok",     action_ok);
    n.add_action ("decline_id", "Cancel", action_decline);

    # indicate to the notification-daemon, that we want to use snap-decisions
    n.set_hint_string ("x-lomiri-snap-decisions", "true");

    # set the button-tint hint so that the right/positive button is tinted and
    # not using the stock clear-color
    n.set_hint_string ("x-lomiri-private-affirmative-tint", "true");
    n.set_hint_string ("x-lomiri-private-rejection-tint", "true");
    n.set_hint_string ("x-lomiri-non-shaped-icon", "true");

    n.show ()
    return n

if __name__ == '__main__':
    if not pynotify.init ("sd-example-using-button-tint-hint"):
        sys.exit (1)

    # call this so we can savely use capabilities dictionary later
    example.initCaps ()

    # show what's supported
    example.printCaps ()

    # be nice and check for required capabilities
    if not example.capabilities['x-lomiri-private-affirmative-tint'] \
        and not example.capabilities['x-lomiri-private-rejection-tint'] \
        and not example.capabilities['x-lomiri-snap-decisions']:
        sys.exit (2)

    loop = gobject.MainLoop ()
    n = pushNotification ("Question", "Would you say Ok or Cancel?", "search")
    n.connect ("closed", example.closedHandler, loop)
    loop.run ()



#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info:
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x sd-example-incoming-call.py
##    ./sd-example-incoming-call.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys
import time
import pynotify
import gobject
import example

def action_decline_1 (notification, action):
    if action == "action_decline_1":
        print("End + Answer")
    else:
        print("That should not have happened (action_decline_1)!")

def action_decline_2 (notification, action):
    if action == "action_decline_2":
        print("Decline")
    else:
        print("That should not have happened (action_decline_2)!")

def action_decline_3 (notification, action):
    if action == "action_decline_3":
        print("I missed your call - can you call me now?")
    else:
        print("That should not have happened (action_decline_3)!")

def action_decline_4 (notification, action):
    if action == "action_decline_4":
        print("I'm running late. I'm on my way.")
    else:
        print("That should not have happened (action_decline_4)!")

def action_decline_5 (notification, action):
    if action == "action_decline_5":
        print("I'm busy at the moment. I'll call later.")
    else:
        print("That should not have happened (action_decline_5)!")

def action_decline_6 (notification, action):
    if action == "action_decline_6":
        print("Custom")
    else:
        print("That should not have happened (action_decline_6)!")

def action_accept (notification, action):
    if action == "action_accept":
        print("Hold + Answer")
    else:
        print("That should not have happened (action_accept)!")

def pushNotification (title, body, icon):
    n = pynotify.Notification (title, body, icon);

    # NOTE: the order in which actions are added is important... positive
    # always comes first!
    n.add_action ("action_accept", "Hold + Answer", action_accept);
    n.add_action ("action_decline_1", "End + Answer", action_decline_1);
    n.add_action ("action_decline_2", "Decline", action_decline_2);
    n.add_action ("action_decline_3", "message:I missed your call - can you call me now?", action_decline_3);
    n.add_action ("action_decline_4", "message:I'm running late. I'm on my way.", action_decline_4);
    n.add_action ("action_decline_5", "message:I'm busy at the moment. I'll call later.", action_decline_5);
    n.add_action ("action_decline_6", "edit:Custom", action_decline_6);

    # indicate to the notification-daemon, that we want to use snap-decisions
    n.set_hint_string ("x-lomiri-snap-decisions", "true");
    n.set_hint_string ("x-lomiri-snap-decisions-swipe", "true");
    n.set_hint_string ("x-lomiri-private-affirmative-tint", "true");
    n.set_hint_string ("x-lomiri-private-rejection-tint", "true");
    n.set_hint_string ("x-lomiri-secondary-icon", "incoming-call");
    n.set_urgency (pynotify.URGENCY_CRITICAL)

    n.show ()
    return n

if __name__ == '__main__':
    if not pynotify.init ("sd-example-incoming-call"):
        sys.exit (1)

    # call this so we can savely use capabilities dictionary later
    example.initCaps ()

    # show what's supported
    example.printCaps ()

    # be nice and check for required capabilities
    if not example.capabilities['x-lomiri-snap-decisions']:
        sys.exit (2)

    loop = gobject.MainLoop ()
    n = pushNotification ("Incoming call",
                          "Frank Zappa\n+44 (0)7736 027340",
                          os.getcwd() + "/assets/avatar4.jpg")
    n.connect ("closed", example.closedHandler, loop)

    loop.run ()



#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x update-notifications.py
##    ./update-notifications.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys
import time
import pynotify
import example

if __name__ == '__main__':
        if not pynotify.init ("update-notifications"):
                sys.exit (1)

        # call this so we can savely use capabilities dictionary later
        example.initCaps ()

        # show what's supported
        example.printCaps ()

        # try the icon-summary-body case
        n = pynotify.Notification (
                        "Inital notification (1. notification)",
                        "This is the original content of this notification-bubble.",
                        os.getcwd() + "/assets/avatar1.jpg")
        n.show ()
        time.sleep (2); # simulate app activity

        # update the current notification with new content
        n.update ("Updated notification (1. notification)",
                  "Here the same bubble with new title- and body-text, even the icon can be changed on the update.",
                  os.getcwd() + "/assets/avatar2.jpg")
        n.show ();
        time.sleep (4); # wait longer now

        # create a new bubble using the icon-summary-body layout
        n = pynotify.Notification (
                        "Initial layout (2. notification)",
                        "This bubble uses the icon-title-body layout with a secondary icon.",
                        os.getcwd() + "/assets/avatar3.jpg")
        n.set_hint_string ("x-lomiri-secondary-icon", "message");
        n.show ()
        time.sleep (2); # simulate app activity

        # now update current bubble again, but change the layout
        n.clear_hints()
        n.update ("Updated layout (2. notification)",
                  "After the update we now have a bubble using the title-body layout.",
                  " ")
        n.show ()



#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info:
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x sd-example-simunlock.py
##    ./sd-example-simunlock.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys

from gi.repository import Gio, GLib, Notify

APPLICATION_ID = 'com.canonical.indicator.network.example'
SIM_UNLOCK_MENU_PATH = '/com/canonical/indicator/network/example/unlocksim'
SIM_UNLOCK_ACTION_PATH = '/com/canonical/indicator/network/example/unlocksim'

def quit_callback(notification, loop):
    global connection
    global exported_action_group_id
    global exported_menu_model_id

    connection.unexport_action_group (exported_action_group_id)
    connection.unexport_menu_model (exported_menu_model_id)

    loop.quit()

def activate (action, variant):
    global n

    if not variant.get_boolean():
        print("Cancel")
        n.close()

def simpin_changed (action, variant):
    global n
    pin = variant.get_string();
    print(("PIN entered: " + pin))
    n.close()

def bus_acquired(bus, name):
    # menu
    unlock_menu = Gio.Menu();
    pin_unlock = Gio.MenuItem.new ("", "notifications.simunlock");
    pin_unlock.set_attribute_value ("x-lomiri-type", GLib.Variant.new_string("com.canonical.snapdecision.pinlock"));
    unlock_menu.append_item (pin_unlock);

    # actions
    unlock_actions = Gio.SimpleActionGroup.new();
    action = Gio.SimpleAction.new_stateful("simunlock", GLib.VariantType.new("b"), GLib.Variant.new_string(""));
    action.connect ("change-state", simpin_changed);
    action.connect ("activate", activate)
    unlock_actions.insert (action);

    global connection
    connection = bus

    global exported_action_group_id
    exported_action_group_id = connection.export_action_group(SIM_UNLOCK_ACTION_PATH, unlock_actions)

    global exported_menu_model_id
    exported_menu_model_id = connection.export_menu_model(SIM_UNLOCK_MENU_PATH, unlock_menu)

def pushNotification (title, body, icon):
    simNotification = Notify.Notification.new(title, body, icon);

    # create the menu-model
    menu_model_actions = GLib.VariantBuilder.new (GLib.VariantType.new ("a{sv}"));
    entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("notifications"),
            GLib.Variant.new_variant(GLib.Variant.new_string(SIM_UNLOCK_ACTION_PATH)));
    menu_model_actions.add_value (entry);

    menu_model_paths = GLib.VariantBuilder.new (GLib.VariantType.new ("a{sv}"));
    entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("busName"),
            GLib.Variant.new_variant(GLib.Variant.new_string(APPLICATION_ID)));
    menu_model_paths.add_value (entry);
    entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("menuPath"),
            GLib.Variant.new_variant(GLib.Variant.new_string(SIM_UNLOCK_MENU_PATH)));
    menu_model_paths.add_value (entry);
    entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("actions"),
            GLib.Variant.new_variant(menu_model_actions.end()));
    menu_model_paths.add_value (entry);

    simNotification.set_hint ("x-lomiri-private-menu-model", menu_model_paths.end ());

    # indicate to the notification-daemon, that we want to use snap-decisions
    simNotification.set_hint_string ("x-lomiri-snap-decisions", "true");
    simNotification.set_hint_string ("x-lomiri-private-button-tint", "true");

    Gio.bus_own_name(Gio.BusType.SESSION, APPLICATION_ID, 0, bus_acquired, None, None)

    return simNotification

if __name__ == '__main__':
    if not Notify.init("sd-example-simunlock"):
        sys.exit (1)

    connection = None
    exported_menu_model_id = 0
    exported_action_group_id = 0
    pin = "0000"

    loop = GLib.MainLoop()
    global n
    n = pushNotification ("", "", "")
    n.connect('closed', quit_callback, loop)
    n.show ()

    loop.run()



#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x sound.py
##    ./sound.py
##
## Copyright 2014 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys
import pynotify
import gobject
import example

if __name__ == '__main__':
	if not pynotify.init ("sound"):
		sys.exit (1)

	# call this so we can savely use capabilities dictionary later
	example.initCaps ()

	# show what's supported
	example.printCaps ()

	loop = gobject.MainLoop ()

	# try the sound support
	n = pynotify.Notification ("Lotsof N. Oise",
				   "With the popping up of this notification, you should hear a sound being played.",
				   os.getcwd() + "/assets/avatar2.jpg")
	n.set_hint_string ("sound-file", "/usr/share/sounds/ubports/notifications/Slick.ogg")
	n.show ()
	n.connect ("closed", example.closedHandler, loop)
	loop.run ()



#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly with the new Qt/QML-based
##    implementation of NotifyOSD
##
## Run:
##    chmod +x append-hint-example.py
##    ./append-hint-example.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys
import time
import pynotify
import example

def pushNotification (title, body, icon, secondaryIcon):
	n = pynotify.Notification (title, body, icon);
	n.set_hint_string ("x-lomiri-append", "true");
	n.set_hint_string ("x-lomiri-secondary-icon", secondaryIcon);
	n.show ()
	time.sleep (3) # simulate a user typing

if __name__ == '__main__':
	if not pynotify.init ("append-hint-example"):
		sys.exit (1)

	# call this so we can savely use capabilities dictionary later
	example.initCaps ()

	# show what's supported
	example.printCaps ()

	# be nice and check for required capabilities
	if not example.capabilities['x-lomiri-append']:
		sys.exit (2)

	# try the append-hint 
	if example.capabilities['x-lomiri-append']:
		pushNotification ("Cole Raby",
				  "Hey Bro Coly!",
				  os.getcwd() + "/assets/avatar1.jpg",
				  os.getcwd() + "/assets/icon_facebook.png")

		pushNotification ("Cole Raby",
				  "What's up dude?",
				  os.getcwd() + "/assets/avatar1.jpg",
				  os.getcwd() + "/assets/icon_facebook.png")

		pushNotification ("Cole Raby",
				  "Did you watch the air-race in Oshkosh last week?",
				  os.getcwd() + "/assets/avatar1.jpg",
				  os.getcwd() + "/assets/icon_facebook.png")


		pushNotification ("Cole Raby",
				  "Phil owned the place like no one before him!",
				  os.getcwd() + "/assets/avatar1.jpg",
				  os.getcwd() + "/assets/icon_facebook.png")

		pushNotification ("Cole Raby",
				  "Did really everything in the race work according to regulations?",
				  os.getcwd() + "/assets/avatar1.jpg",
				  os.getcwd() + "/assets/icon_facebook.png")

		pushNotification ("Cole Raby",
				  "Somehow I think to remember Burt Williams did cut corners and was not punished for this.",
				  os.getcwd() + "/assets/avatar1.jpg",
				  os.getcwd() + "/assets/icon_facebook.png")

		pushNotification ("Cole Raby",
				  "Hopefully the referees will watch the videos of the race.",
				  os.getcwd() + "/assets/avatar1.jpg",
				  os.getcwd() + "/assets/icon_facebook.png")

		pushNotification ("Cole Raby",
				  "Burt could get fined with US$ 50000 for that rule-violation :)",
				  os.getcwd() + "/assets/avatar1.jpg",
				  os.getcwd() + "/assets/icon_facebook.png")

	else:
		print("The daemon does not support the x-lomiri-append hint!")




#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info: 
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x icon-updating.py
##    ./icon-updating.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import sys
import time
import pynotify
import example
import gtk

if __name__ == '__main__':
	if not pynotify.init ("icon-updating"):
		sys.exit (1);

	# call this so we can savely use capabilities dictionary later
	example.initCaps ();

	# show what's supported
	example.printCaps ();

	# create new notification, set icon using hint "image_path"
	n = pynotify.Notification ("Test 1/3",
                                   "Set icon via hint \"image_path\" to logo-icon.");
	n.set_hint_string ("image_path",
                           "/usr/share/icons/Humanity/places/64/distributor-logo.svg");
	n.show ();
	time.sleep (4); # wait a bit

	# update notification using hint image_data
	n.clear_hints ();
	n.update ("Test 2/3",
                  "Set icon via hint \"image_data\" to avatar-photo.");
	pixbuf = gtk.gdk.pixbuf_new_from_file ("../icons/avatar.png");
	n.set_icon_from_pixbuf (pixbuf);
	n.show ();
	time.sleep (4); # wait a bit

	# update notification using icon-parameter directly
	n.clear_hints ();
	n.update ("Test 3/3",
                  "Set icon via icon-parameter directly to totem-icon.",
                  "totem");
	n.show ();



#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info:
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x interactive-notification.py
##    ./interactive-notification.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys
import pynotify
import gobject
import example

def action_callback (notification, action):
    if action == "action_id":
        print("Triggering action")
    else:
        print("That should not have happened (action_id)!")

def pushNotification (icon, value):
    n = pynotify.Notification ("Interactive notification",
                               "Click this notification to trigger the attached action.",
                               icon);
    n.set_hint_string ("x-lomiri-switch-to-application", value);
    n.set_hint_string ("x-lomiri-secondary-icon", "message");
    n.add_action ("action_id", "dummy", action_callback);
    return n

if __name__ == '__main__':
    if not pynotify.init ("interactive-notification"):
        sys.exit (1)

    # call this so we can savely use capabilities dictionary later
    example.initCaps ()

    # show what's supported
    example.printCaps ()

    # try the icon-summary-body case
    loop = gobject.MainLoop ()
    n = pushNotification (os.getcwd() + "/assets/avatar4.jpg", "true")
    n.connect ("closed", example.closedHandler, loop)
    n.show ()
    loop.run ()



#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info:
##    Example of how to use libnotify correctly and at the same time comply to
##    the new jaunty notification spec (read: visual guidelines)
##
## Run:
##    chmod +x example.py
##    ./example.py
##
## Copyright 2012 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import pynotify

# even in Python this is globally nasty :), do something nicer in your own code
capabilities = {'actions':                              False,
        'body':                                 False,
        'body-hyperlinks':                      False,
        'body-images':                          False,
        'body-markup':                          False,
        'icon-multi':                           False,
        'icon-static':                          False,
        'sound':                                False,
        'sound-file':                           False,
        'suppress-sound':                       False,
        'image/svg+xml':                        False,
        'urgency':                              False,
        'value':                                False,
        'x-lomiri-value-bar-tint':           False,
        'x-lomiri-private-synchronous':      False,
        'x-lomiri-private-icon-only':        False,
        'x-lomiri-truncation':               False,
        'x-lomiri-snap-decisions':             False,
        'x-lomiri-snap-decisions-timeout':   False,
        'x-lomiri-snap-decisions-swipe':     False,
        'x-lomiri-switch-to-application':    False,
        'x-lomiri-secondary-icon':           False,
        'x-lomiri-private-affirmative-tint': False,
        'x-lomiri-private-rejection-tint':   False,
        'x-lomiri-private-menu-model':       False,
        'x-lomiri-non-shaped-icon':          False}

def initCaps ():
    caps = pynotify.get_server_caps ()
    if caps is None:
        print("Failed to receive server caps.")
        sys.exit (1)

    for cap in caps:
        capabilities[cap] = True

def printCaps ():
    info = pynotify.get_server_info ()
    print("Name:          " + info["name"])
    print("Vendor:        " + info["vendor"])
    print("Version:       " + info["version"])
    print("Spec. Version: " + info["spec-version"])

    caps = pynotify.get_server_caps ()
    if caps is None:
        print("Failed to receive server caps.")
        sys.exit (1)

    print("Supported capabilities/hints:")
    if capabilities['actions']:
        print("\tactions")
    if capabilities['body']:
        print("\tbody")
    if capabilities['body-hyperlinks']:
        print("\tbody-hyperlinks")
    if capabilities['body-images']:
        print("\tbody-images")
    if capabilities['body-markup']:
        print("\tbody-markup")
    if capabilities['icon-multi']:
        print("\ticon-multi")
    if capabilities['icon-static']:
        print("\ticon-static")
    if capabilities['sound']:
        print("\tsound")
    if capabilities['sound-file']:
        print("\tsound-file")
    if capabilities['suppress-sound']:
        print("\tsuppress-sound")
    if capabilities['urgency']:
        print("\turgency")
    if capabilities['value']:
        print("\tvalue")
    if capabilities['x-lomiri-value-bar-tint']:
        print("\tx-lomiri-value-bar-tint")
    if capabilities['image/svg+xml']:
        print("\timage/svg+xml")
    if capabilities['x-lomiri-private-synchronous']:
        print("\tx-lomiri-private-synchronous")
    if capabilities['x-lomiri-private-icon-only']:
        print("\tx-lomiri-private-icon-only")
    if capabilities['x-lomiri-truncation']:
        print("\tx-lomiri-truncation")
    if capabilities['x-lomiri-snap-decisions']:
        print("\tx-lomiri-snap-decisions")
    if capabilities['x-lomiri-snap-decisions-timeout']:
        print("\tx-lomiri-snap-decisions-timeout")
    if capabilities['x-lomiri-snap-decisions-swipe']:
        print("\tx-lomiri-snap-decisions-swipe")
    if capabilities['x-lomiri-switch-to-application']:
        print("\tx-lomiri-switch-to-application")
    if capabilities['x-lomiri-secondary-icon']:
        print("\tx-lomiri-secondary-icon")
    if capabilities['x-lomiri-private-affirmative-tint']:
        print("\tx-lomiri-private-affirmative-tint")
    if capabilities['x-lomiri-private-rejection-tint']:
        print("\tx-lomiri-private-rejection-tint")
    if capabilities['x-lomiri-private-menu-model']:
        print("\tx-lomiri-private-menu-model")
    if capabilities['x-lomiri-non-shaped-icon']:
        print("\tx-lomiri-non-shaped-icon")

    print("Notes:")
    if info["name"] == "notify-osd":
        print("\tx- and y-coordinates hints are ignored")
        print("\texpire-timeout is ignored")
        print("\tbody-markup is accepted but filtered")
    else:
        print("\tnone")

def closedHandler (notification, loop):
    print("\"closed\"-handler called")
    loop.quit ()



#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info:
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x icon-value.py
##    ./icon-value.py
##
## Copyright 2014 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import sys
import time
import pynotify
import example

def pushNotification (icon, value):
    n = pynotify.Notification ("Volume", # for a11y-reasons supply something meaning full
                               "",      # this needs to be empty!
                               icon);
    n.set_hint_int32 ("value", value);
    n.set_hint_string ("x-lomiri-private-synchronous", "true");
    n.set_hint_string ("x-lomiri-non-shaped-icon", "true");
    n.show ()
    return n

def updateNotification (n, icon, value):
    n.clear_hints()
    n.update("Volume", # for a11y-reasons supply something meaning full
             ("", "High Volume")[bool(value > 75)],
             icon);
    n.set_hint_int32 ("value", value);

    if value > 75:
        n.set_hint_string ("x-lomiri-value-bar-tint", "true");
    n.set_hint_string ("x-lomiri-private-synchronous", "true");
    n.set_hint_string ("x-lomiri-non-shaped-icon", "true");
    n.show ()

if __name__ == '__main__':
    if not pynotify.init ("icon-value"):
        sys.exit (1)

    # call this so we can savely use capabilities dictionary later
    example.initCaps ()

    # show what's supported
    example.printCaps ()

    # try the icon-value case
    if example.capabilities['x-lomiri-private-synchronous'] and \
        example.capabilities['x-lomiri-non-shaped-icon'] and \
        example.capabilities['value'] and \
        example.capabilities['x-lomiri-value-bar-tint']:
        n = pushNotification ("audio-volume-muted", 0);
        time.sleep (1)
        updateNotification (n, "audio-volume-low", 25);
        time.sleep (1)
        updateNotification (n, "audio-volume-medium", 50);
        time.sleep (1)
        updateNotification (n, "audio-volume-high", 76);
        time.sleep (1)
        updateNotification (n, "audio-volume-high", 100);
        time.sleep (1)

        # trigger "overshoot"-effect
        updateNotification (n, "audio-volume-high", 100);
        time.sleep (1)
        updateNotification (n, "audio-volume-high", 76);
        time.sleep (1)
        updateNotification (n, "audio-volume-medium", 50);
        time.sleep (1)
        updateNotification (n, "audio-volume-low", 25);
        time.sleep (1)
        updateNotification (n, "audio-volume-muted", 0);
        time.sleep (1)

    else:
        print("The daemon does not support the x-lomiri-private-icon-only, x-lomiri-non-shaped-icon, value and value-hint hints!")



#!/usr/bin/python3

################################################################################
##3456789 123456789 123456789 123456789 123456789 123456789 123456789 123456789
##      10        20        30        40        50        60        70        80
##
## Info:
##    Example of how to use libnotify correctly
##
## Run:
##    chmod +x sd-example-password-entry.py
##    ./sd-example-password-entry.py
##
## Copyright 2013 Canonical Ltd.
##
## Author:
##    Mirco "MacSlow" Mueller <mirco.mueller@canonical.com>
##
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License version 3, as published
## by the Free Software Foundation.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranties of
## MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
## PURPOSE.  See the GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License along
## with this program.  If not, see <http://www.gnu.org/licenses/>.
##
################################################################################

import os
import sys

from gi.repository import Gio, GLib, Notify

APPLICATION_ID = 'com.canonical.snapdecisions'
PASSWORD_MENU_PATH = '/com/canonical/snapdecisions/password'
PASSWORD_ACTION_PATH = '/com/canonical/snapdecisions/password'

def quit_callback(notification, loop):
    global connection
    global exported_action_group_id
    global exported_menu_model_id

    connection.unexport_action_group (exported_action_group_id)
    connection.unexport_menu_model (exported_menu_model_id)

    loop.quit()

def cancel (notification, action, data):
    if action == "cancel":
        print("Cancel")
    else:
        print("That should not have happened (cancel)!")

def connect (notification, action, data):
    if action == "connect":
        global password
        print(("password entered: " + password))
    else:
        print("That should not have happened (connect)!")

def password_changed (action, variant):
    global password
    password = variant.get_string();

def bus_acquired(bus, name):
    # menu
    menu = Gio.Menu();

    password_item = Gio.MenuItem.new ("Password:", "notifications.password");
    password_item.set_attribute_value ("x-lomiri-type", GLib.Variant.new_string("com.canonical.snapdecision.textfield"));
    password_item.set_attribute_value ('x-echo-mode-password', GLib.Variant.new_boolean(True))
    menu.append_item (password_item);

    # actions
    actions = Gio.SimpleActionGroup.new();
    password_action = Gio.SimpleAction.new_stateful("password", GLib.VariantType.new("s"), GLib.Variant.new_string(""));
    password_action.connect ("change-state", password_changed);
    actions.insert (password_action);

    global connection
    connection = bus

    global exported_action_group_id
    exported_action_group_id = connection.export_action_group(PASSWORD_ACTION_PATH, actions)

    global exported_menu_model_id
    exported_menu_model_id = connection.export_menu_model(PASSWORD_MENU_PATH, menu)

def pushNotification (title, body, icon):
    n = Notify.Notification.new(title, body, icon);

    # NOTE: the order in which actions are added is important... positive
    # always comes first!
    n.add_action ("connect", "Connect", connect, None, None);
    n.add_action ("cancel", "Cancel", cancel, None, None);

    # create the menu-model
    menu_model_actions = GLib.VariantBuilder.new (GLib.VariantType.new ("a{sv}"));
    entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("notifications"),
            GLib.Variant.new_variant(GLib.Variant.new_string(PASSWORD_ACTION_PATH)));
    menu_model_actions.add_value (entry);

    menu_model_paths = GLib.VariantBuilder.new (GLib.VariantType.new ("a{sv}"));
    entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("busName"),
            GLib.Variant.new_variant(GLib.Variant.new_string(APPLICATION_ID)));
    menu_model_paths.add_value (entry);
    entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("menuPath"),
            GLib.Variant.new_variant(GLib.Variant.new_string(PASSWORD_MENU_PATH)));
    menu_model_paths.add_value (entry);
    entry = GLib.Variant.new_dict_entry(GLib.Variant.new_string("actions"),
            GLib.Variant.new_variant(menu_model_actions.end()));
    menu_model_paths.add_value (entry);

    n.set_hint ("x-lomiri-private-menu-model", menu_model_paths.end ());

    # indicate to the notification-daemon, that we want to use snap-decisions
    n.set_hint ("x-lomiri-snap-decisions", GLib.Variant.new_string("true"));
    n.set_hint ("x-lomiri-snap-decisions-timeout", GLib.Variant.new_int32(90000));
    n.set_hint ("x-lomiri-private-affirmative-tint", GLib.Variant.new_string("true"));
    n.set_hint ("x-lomiri-private-rejection-tint", GLib.Variant.new_string("true"));
    n.set_hint ("x-lomiri-non-shaped-icon", GLib.Variant.new_string("true"));

    Gio.bus_own_name(Gio.BusType.SESSION, APPLICATION_ID, 0, bus_acquired, None, None)

    return n

if __name__ == '__main__':
    if not Notify.init("sd-example-password-entry"):
        sys.exit (1)

    connection = None
    exported_menu_model_id = 0
    exported_action_group_id = 0
    password = ""

    loop = GLib.MainLoop()
    n = pushNotification ("Connect to \"linksys\"", "", "image://theme/nm-signal-100")
    n.connect('closed', quit_callback, loop)
    n.show ()

    loop.run()
